1. Keep pull requests short-lived to minimize merge conflicts and simplify reviews.
2. Embrace code discussion; we're here to improve each other's skills through constructive feedback.
3. Communicate your work – let others know if you're working on something, or create a pull request.
4. Don't aim for perfection before publishing a pull request; seek advice from colleagues on drafts.
5. Report issues for project improvements; help identify and fix deficiencies.
6. Update the changelog with any modifications made.
7. Push only the necessary files in pull requests; avoid unnecessary local or configuration changes.
8. If your code can be tested, please provide tests to enhance verification and understanding.
9. We don't want to add big dependencies
10. We should always keep documentation up to date
